import type { Ref, ToRefs } from 'vue';
/** 经过main.ts初始化后去除响应式的DefParams值 */
export declare let defParams: SystemParametersType;
/** main初始化时传入的函数 */
export declare const CrudRequest: Ref<any>;
/** 系统培训初始化函数 */
export declare const InitSys: (Options: any) => void;
/** Props传参初始化 */
export declare const Initializer: (props: any) => void;
/** 系统参数 */
export declare function UseParam(): {
    debug: Ref<boolean>;
    isAfterMountQuery: Ref<boolean>;
    isOpenSearchForm: Ref<boolean>;
    Form_LabelWidth: Ref<number>;
    Table_isOpenIndex: Ref<boolean>;
    Table_isOpenMultipleSelection: Ref<boolean>;
    Table_isOpenExpand: Ref<boolean>;
    Table_ExpandColumn: Ref<number>;
    Table_IsShowMenu: Ref<boolean>;
    Table_MenuWidth: Ref<number>;
    Table_MenuAlign: Ref<"left" | "center" | "right">;
    Page_PageSizes: Ref<number[]>;
    Page_PageParams: Ref<{
        current: number;
        pageSize: number;
        total: number;
    }>;
    Page_Layout: Ref<string>;
    Page_isHideOnSinglePage: Ref<boolean>;
    Dialog_Width: Ref<number>;
    Dialog_isFullscreen: Ref<boolean>;
    Dialog_isCloseOnPressEscape: Ref<boolean>;
    Dialog_isCloseOnClickModal: Ref<boolean>;
    Dialog_isFooterButton: Ref<boolean>;
    ApiName: Ref<{
        query: string;
        add: string;
        edit: string;
        delete: string;
        deleteFlag: string;
        remove: string;
    }>;
    Permission: Ref<{
        add: string;
        edit: string;
        delete: string;
        deleteFlag: string;
        remove: string;
    }>;
    Permissions: Ref<string[]>;
};
/** 组件参数 */
export declare function UseState(): ToRefs<CrusStateType>;
/** Props参数 */
export declare function UseProps(): {
    url: Ref<string>;
    source: Ref<{
        filter: string[];
        editor: string[];
        column: string[];
        expand: string[];
        columns: columnsType;
    }>;
    rowKey?: Ref<string | undefined> | undefined;
    rowKeys?: Ref<string[] | undefined> | undefined;
    keyName?: Ref<string | undefined> | undefined;
    watchData?: Ref<{
        id: string;
        data: {
            url: string;
            name: string;
            data: any;
            key: string;
            label: string | string[];
            value: string;
        }[];
    }[] | undefined> | undefined;
    hooks?: Ref<{
        [x: string]: any;
        debug?: boolean | undefined;
        beforeSubmitHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        beforedisabledHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        afterdisabledHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        beforeAddHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        beforeEditHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        beforeQueryHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        afterQueryHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        beforeDeteleHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        afterDeteleHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        beforeBatchDeteleHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        afterBatchDeteleHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
        beforeTableLazyHandler?: (({ CrudState, Data }: {
            CrudState: Ref<CrusStateType>;
            Data: any;
        }) => boolean) | undefined;
    } | undefined> | undefined;
    Table_Attributes?: Ref<object | undefined> | undefined;
    isObjEqual?: Ref<boolean | undefined> | undefined;
    debug?: Ref<boolean | undefined> | undefined;
    isAfterMountQuery?: Ref<boolean | undefined> | undefined;
    isOpenSearchForm?: Ref<boolean | undefined> | undefined;
    Form_LabelWidth?: Ref<number | undefined> | undefined;
    Table_isOpenIndex?: Ref<boolean | undefined> | undefined;
    Table_isOpenMultipleSelection?: Ref<boolean | undefined> | undefined;
    Table_isOpenExpand?: Ref<boolean | undefined> | undefined;
    Table_ExpandColumn?: Ref<number | undefined> | undefined;
    Table_IsShowMenu?: Ref<boolean | undefined> | undefined;
    Table_MenuWidth?: Ref<number | undefined> | undefined;
    Table_MenuAlign?: Ref<"left" | "center" | "right" | undefined> | undefined;
    Page_PageSizes?: Ref<number[] | undefined> | undefined;
    Page_PageParams?: Ref<{
        current?: number | undefined;
        pageSize?: number | undefined;
        total?: number | undefined;
    } | undefined> | undefined;
    Page_Layout?: Ref<string | undefined> | undefined;
    Page_isHideOnSinglePage?: Ref<boolean | undefined> | undefined;
    Dialog_Width?: Ref<number | undefined> | undefined;
    Dialog_isFullscreen?: Ref<boolean | undefined> | undefined;
    Dialog_isCloseOnPressEscape?: Ref<boolean | undefined> | undefined;
    Dialog_isCloseOnClickModal?: Ref<boolean | undefined> | undefined;
    Dialog_isFooterButton?: Ref<boolean | undefined> | undefined;
    ApiName?: Ref<{
        query?: string | undefined;
        add?: string | undefined;
        edit?: string | undefined;
        delete?: string | undefined;
        deleteFlag?: string | undefined;
        remove?: string | undefined;
    } | undefined> | undefined;
    Permission?: Ref<{
        add?: string | undefined;
        edit?: string | undefined;
        delete?: string | undefined;
        deleteFlag?: string | undefined;
        remove?: string | undefined;
    } | undefined> | undefined;
    Permissions?: Ref<string[] | undefined> | undefined;
};
/** 增删改查等操作方法 */
export declare const UseFun: () => {
    queryRecord: () => void;
    addRecord: () => void;
    editRecord: (row: any) => void;
    handleSubmit: (formEl: any) => Promise<void>;
    delFlag: (row: any) => void;
    deleteRecord: (row: any) => void;
    deleteMulRecord: () => void;
};
/** DeBug */
export declare function CrudDebug(...params: any): void;
